@@ -101,6 +101,12 @@ module RHC::Commands
       end.join(', ')
 
       env = collect_env_vars(arg_envs.concat(Array(options.env)))
+      if options.env && env.empty?
+        raise RHC::EnvironmentVariableNotProvidedException.new(
+        "Environment variable(s) not provided.\n" +
+        "Please provide at least one environment variable using the syntax VARIABLE=VALUE. VARIABLE can only contain letters, digits and underscore ('_') and can't begin with a digit.")
+      end
+
       if env.present? && !rest_domain.supports_add_application_with_env_vars?
         env = []
         warn "Server does not support environment variables."
@@ -179,7 +185,7 @@ module RHC::Commands
               warn "not complete"
               add_issue("Jenkins failed to install - #{e}",
                         "Installing jenkins and jenkins-client",
-                        "rhc create-app jenkins",
+                        "rhc create-app jenkins jenkins-1",
                         "rhc add-cartridge jenkins-client -a #{rest_app.name}")
             end
           end
@@ -432,10 +438,16 @@ module RHC::Commands
         domain, app = discover_domain_and_app
         gear_info = rest_client.find_application_gear_groups_endpoints(domain, app).map do |group|
           group.gears.map do |gear|
+            color_cart = if gear['endpoints'].present?
+              e = gear['endpoints'].collect{ |c| c['cartridge_name'] }.uniq
+              lambda { |c| e.include?(c) ? color(c, :green) : c }
+            else
+              lambda { |c| c }
+            end
             [
               gear['id'],
               gear['state'] == 'started' ? color(gear['state'], :green) : color(gear['state'], :yellow),
-              (gear['endpoints'].blank? ? group.cartridges : gear['endpoints']).collect{ |c| c['cartridge_name'] || c['name'] }.join(' '),
+              group.cartridges.collect{ |c| color_cart.call(c['name']) }.join(' '),
               group.gear_profile,              
               gear['region'],
               gear['zone'],
